antares.apps.client.templatetags package
========================================

Submodules
----------

antares.apps.client.templatetags.client\_user\_relation\_tags module
--------------------------------------------------------------------

.. automodule:: antares.apps.client.templatetags.client_user_relation_tags
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.client.templatetags
   :members:
   :undoc-members:
   :show-inheritance:
